==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerExternalNodePortFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

public interface KafkaListenerExternalNodePortFluent<A extends KafkaListenerExternalNodePortFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public boolean isTls();
    public A withTls(boolean tls);
    public Boolean hasTls();
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public NodePortListenerOverride getOverrides();
    public NodePortListenerOverride buildOverrides();
    public A withOverrides(NodePortListenerOverride overrides);
    public Boolean hasOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> withNewOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> withNewOverridesLike(NodePortListenerOverride item);
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> editOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> editOrNewOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> editOrNewOverridesLike(NodePortListenerOverride item);
    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public NodePortListenerConfiguration getConfiguration();
    public NodePortListenerConfiguration buildConfiguration();
    public A withConfiguration(NodePortListenerConfiguration configuration);
    public Boolean hasConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> withNewConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> withNewConfigurationLike(NodePortListenerConfiguration item);
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> editConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> editOrNewConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> editOrNewConfigurationLike(NodePortListenerConfiguration item);

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}
    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerOverrideFluent<KafkaListenerExternalNodePortFluent.OverridesNested<N>>{

        
    public N and();    public N endOverrides();
}
    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerConfigurationFluent<KafkaListenerExternalNodePortFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerExternalNodePortFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

public interface KafkaListenerExternalNodePortFluent<A extends KafkaListenerExternalNodePortFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public boolean isTls();
    public A withTls(boolean tls);
    public Boolean hasTls();
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public java.util.List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(java.util.List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public NodePortListenerOverride getOverrides();
    public NodePortListenerOverride buildOverrides();
    public A withOverrides(NodePortListenerOverride overrides);
    public Boolean hasOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> withNewOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> withNewOverridesLike(NodePortListenerOverride item);
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> editOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> editOrNewOverrides();
    public KafkaListenerExternalNodePortFluent.OverridesNested<A> editOrNewOverridesLike(NodePortListenerOverride item);
    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public NodePortListenerConfiguration getConfiguration();
    public NodePortListenerConfiguration buildConfiguration();
    public A withConfiguration(NodePortListenerConfiguration configuration);
    public Boolean hasConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> withNewConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> withNewConfigurationLike(NodePortListenerConfiguration item);
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> editConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> editOrNewConfiguration();
    public KafkaListenerExternalNodePortFluent.ConfigurationNested<A> editOrNewConfigurationLike(NodePortListenerConfiguration item);

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerExternalNodePortFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}
    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerOverrideFluent<KafkaListenerExternalNodePortFluent.OverridesNested<N>>{

        
    public N and();    public N endOverrides();
}
    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerConfigurationFluent<KafkaListenerExternalNodePortFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}
